@@ -6,7 +6,7 @@ package Mite::Attribute;
 use Mite::Miteception;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001012';
+our $VERSION   = '0.001013';
 
 has class =>
   is            => rw,
@@ -201,9 +201,13 @@ sub _build_clearer { undef; }
 sub _build_alias_is_for {
     my $self = shift;
     return undef unless @{ $self->alias };
-    return $self->accessor ? 'accessor' : $self->reader ? 'reader' : undef
-        $self->is eq rw;
-    $self->reader ? 'reader' : $self->accessor ? 'accessor' : undef;
+    my @seek_order = $self->is eq rw
+        ? qw( accessor reader writer )
+        : qw( reader accessor writer );
+    for my $sought ( @seek_order ) {
+        return $sought if $self->$sought;
+    }
+    return undef;
 }
 
 sub _all_aliases {
@@ -284,12 +288,6 @@ sub has_simple_default {
     return !ref $self->default;
 }
 
-sub _empty {
-    my $self = shift;
-
-    return ';';
-}
-
 sub _compile_coercion {
     my ( $self, $expression ) = @_;
     if ( $self->coerce and my $type = $self->type ) {
