@@ -1,5 +1,6 @@
 {
 package Mite::MakeMaker;
+our $USES_MITE = 1;
 use strict;
 use warnings;
 
@@ -28,9 +29,9 @@ defined ${^GLOBAL_PHASE}
     or do   { *Devel::GlobalDestruction::in_global_destruction = sub { undef; } };
 
 sub DESTROY {
-    my $self = shift;
+    my $self  = shift;
     my $class = ref( $self ) || $self;
-    my $meta = ( $Mite::META{$class} ||= $class->__META__ );
+    my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
     my $in_global_destruction = defined ${^GLOBAL_PHASE}
         ? ${^GLOBAL_PHASE} eq 'DESTRUCT'
         : Devel::GlobalDestruction::in_global_destruction();
@@ -49,7 +50,7 @@ sub DESTROY {
 sub __META__ {
     no strict 'refs';
     require mro;
-    my $class = shift; $class = ref($class) || $class;
+    my $class      = shift; $class = ref($class) || $class;
     my $linear_isa = mro::get_linear_isa( $class );
     return {
         BUILD => [
